@@ -7,6 +7,10 @@ from consts import *
 from ModuleCgi import *
 from ModuleBalancer import NOTE_BALANCER
 
+HELPS = [
+    ('modules_handlers_fcgi', "FastCGI")
+]
+
 class ModuleFcgi (ModuleCgiBase):
     PROPERTIES = ModuleCgiBase.PROPERTIES + [
         'balancer'
@@ -15,16 +19,20 @@ class ModuleFcgi (ModuleCgiBase):
     def __init__ (self, cfg, prefix, submit):
         ModuleCgiBase.__init__ (self, cfg, prefix, 'fcgi', submit)
 
+        self.show_script_alias  = False
+        self.show_change_uid    = False
+        self.show_document_root = True
+
     def _op_render (self):
         txt = ModuleCgiBase._op_render (self)
 
-        txt += '<h2>FastCGI specific</h2>'
+        txt += '<h2>%s</h2>' % (_('FastCGI specific'))
 
         table = TableProps()
         prefix = "%s!balancer" % (self._prefix)
         assert (self.submit_url)
-        e = self.AddPropOptions_Reload (table, "Balancer", prefix, 
-                                        modules_available(BALANCERS), NOTE_BALANCER)
+        e = self.AddPropOptions_Reload (table, _("Balancer"), prefix,
+                                        modules_available(BALANCERS), _(NOTE_BALANCER))
         txt += self.Indent (str(table) + e)
         return txt
 
@@ -41,6 +49,6 @@ class ModuleFcgi (ModuleCgiBase):
             name = cfg.value
             props = module_obj_factory (name, self._cfg, pre, self.submit_url)
             props._op_apply_changes (uri, post)
-        
+
         # And CGI changes
         return ModuleCgiBase._op_apply_changes (self, uri, post)
