@@ -3,13 +3,15 @@ from os.path import join
 PREFIX     = "/usr/local"
 LIBDIR     = "/usr/local/lib"
 DATADIR    = "/usr/local/share"
+DOCDIR     = "/usr/local/share/doc/cherokee"
+LOCALEDIR  = "/usr/local/share/locale"
 WWWROOT    = "/var/cherokee"
 SYSCONFDIR = "/etc"
 LOCALSTATE = "/var"
-VERSION    = "0.8.1"
+VERSION    = "0.99.15"
 
-CHEROKEE_SRV_PATH   = join (PREFIX, "sbin/cherokee")
-CHEROKEE_GUARDIAN   = join (PREFIX, "sbin/cherokee-guardian")
+CHEROKEE_SERVER     = join (PREFIX, "sbin/cherokee")
+CHEROKEE_WORKER     = join (PREFIX, "sbin/cherokee-worker")
 CHEROKEE_ADMINDIR   = join (PREFIX, "share/cherokee/admin")
 CHEROKEE_ICONSDIR   = join (PREFIX, "share/cherokee/icons")
 CHEROKEE_THEMEDIR   = join (PREFIX, "share/cherokee/themes")
